@@ -4,9 +4,9 @@
 # An interface to the LBL pcap(3) library.  This module simply
 # bootstraps the extensions defined in Pcap.xs
 #
-# Copyright (C) 2005, 2006 Sebastien Aperghis-Tramoni. All rights reserved.
+# Copyright (C) 2005, 2006, 2007 Sebastien Aperghis-Tramoni. All rights reserved.
 # Copyright (C) 2003 Marco Carnut. All rights reserved. 
-# Copyright (C) 1999-2000 Tim Potter. All rights reserved. 
+# Copyright (C) 1999, 2000 Tim Potter. All rights reserved. 
 # Copyright (C) 1998 Bo Adler. All rights reserved. 
 # Copyright (C) 1997 Peter Lister. All rights reserved. 
 # 
@@ -16,13 +16,42 @@
 package Net::Pcap;
 use strict;
 require Exporter;
-use AutoLoader;
 use Carp;
 
-{   no strict;
-    $VERSION = '0.14';
 
-    @ISA = qw(Exporter DynaLoader);
+# functions names
+my @func_short_names = qw(
+    lookupdev  findalldevs  lookupnet
+    open_live  open_dead  open_offline  loop  breakloop  close  dispatch
+    next  next_ex  compile  compile_nopcap  setfilter  freecode
+    setnonblock  getnonblock
+    dump_open  dump  dump_file  dump_flush  dump_close
+    datalink  set_datalink  datalink_name_to_val  datalink_val_to_name
+    datalink_val_to_description
+    snapshot  is_swapped  major_version  minor_version  stats
+    file  fileno  get_selectable_fd  geterr  strerror  perror
+    lib_version  createsrcstr  parsesrcstr  open  setbuff  setbuff
+    setmode  setmintocopy  getevent  sendpacket
+    sendqueue_alloc  sendqueue_queue  sendqueue_transmit
+);
+
+my @func_long_names = map { "pcap_$_" } @func_short_names;
+
+
+# functions aliases
+{
+    no strict "refs";
+    for my $func (@func_short_names) {
+        *{ __PACKAGE__ . "::pcap_$func" } = \&{ __PACKAGE__ . $func }
+    }
+}
+
+
+{
+    no strict "vars";
+    $VERSION = '0.15';
+
+    @ISA = qw(Exporter);
 
     %EXPORT_TAGS = (
         'bpf' => [qw(
@@ -31,19 +60,21 @@ use Carp;
         )], 
         'datalink' => [qw(
             DLT_AIRONET_HEADER  DLT_APPLE_IP_OVER_IEEE1394  DLT_ARCNET
-            DLT_ARCNET_LINUX  DLT_ATM_CLIP  DLT_ATM_RFC1483  DLT_AURORA  DLT_AX25
-            DLT_CHAOS  DLT_CHDLC  DLT_CISCO_IOS  DLT_C_HDLC  DLT_DOCSIS  DLT_ECONET
-            DLT_EN10MB  DLT_EN3MB  DLT_ENC  DLT_FDDI  DLT_FRELAY  DLT_HHDLC
-            DLT_IBM_SN  DLT_IBM_SP  DLT_IEEE802  DLT_IEEE802_11  DLT_IEEE802_11_RADIO
-            DLT_IEEE802_11_RADIO_AVS  DLT_IPFILTER  DLT_IP_OVER_FC  DLT_JUNIPER_ATM1
-            DLT_JUNIPER_ATM2  DLT_JUNIPER_ES  DLT_JUNIPER_GGSN  DLT_JUNIPER_MFR
-            DLT_JUNIPER_MLFR  DLT_JUNIPER_MLPPP  DLT_JUNIPER_MONITOR  DLT_JUNIPER_SERVICES
-            DLT_LINUX_IRDA  DLT_LINUX_SLL  DLT_LOOP  DLT_LTALK  DLT_NULL  DLT_OLD_PFLOG
-            DLT_PCI_EXP  DLT_PFLOG  DLT_PFSYNC  DLT_PPP  DLT_PPP_BSDOS  DLT_PPP_ETHER
-            DLT_PPP_SERIAL  DLT_PRISM_HEADER  DLT_PRONET  DLT_RAW  DLT_RIO  DLT_SLIP
-            DLT_SLIP_BSDOS  DLT_SUNATM  DLT_SYMANTEC_FIREWALL  DLT_TZSP  DLT_USER0
-            DLT_USER1  DLT_USER2  DLT_USER3  DLT_USER4  DLT_USER5  DLT_USER6  DLT_USER7
-            DLT_USER8  DLT_USER9  DLT_USER10  DLT_USER11  DLT_USER12  DLT_USER13
+            DLT_ARCNET_LINUX  DLT_ATM_CLIP  DLT_ATM_RFC1483  DLT_AURORA
+            DLT_AX25  DLT_CHAOS  DLT_CHDLC  DLT_CISCO_IOS  DLT_C_HDLC
+            DLT_DOCSIS  DLT_ECONET  DLT_EN10MB  DLT_EN3MB  DLT_ENC  DLT_FDDI
+            DLT_FRELAY  DLT_HHDLC  DLT_IBM_SN  DLT_IBM_SP  DLT_IEEE802
+            DLT_IEEE802_11  DLT_IEEE802_11_RADIO  DLT_IEEE802_11_RADIO_AVS
+            DLT_IPFILTER  DLT_IP_OVER_FC  DLT_JUNIPER_ATM1  DLT_JUNIPER_ATM2
+            DLT_JUNIPER_ES  DLT_JUNIPER_GGSN  DLT_JUNIPER_MFR  DLT_JUNIPER_MLFR
+            DLT_JUNIPER_MLPPP  DLT_JUNIPER_MONITOR  DLT_JUNIPER_SERVICES
+            DLT_LINUX_IRDA  DLT_LINUX_SLL  DLT_LOOP  DLT_LTALK  DLT_NULL
+            DLT_OLD_PFLOG  DLT_PCI_EXP  DLT_PFLOG  DLT_PFSYNC  DLT_PPP
+            DLT_PPP_BSDOS  DLT_PPP_ETHER  DLT_PPP_SERIAL  DLT_PRISM_HEADER
+            DLT_PRONET  DLT_RAW  DLT_RIO  DLT_SLIP  DLT_SLIP_BSDOS  DLT_SUNATM
+            DLT_SYMANTEC_FIREWALL  DLT_TZSP  DLT_USER0  DLT_USER1  DLT_USER2
+            DLT_USER3  DLT_USER4  DLT_USER5  DLT_USER6  DLT_USER7  DLT_USER8
+            DLT_USER9  DLT_USER10  DLT_USER11  DLT_USER12  DLT_USER13
             DLT_USER14  DLT_USER15
         )], 
         mode => [qw(
@@ -67,20 +98,19 @@ use Carp;
         )],
         functions => [qw(
             lookupdev  findalldevs  lookupnet
-            open_live  open_dead  open_offline  pcap_open  pcap_close
-            dump_open  pcap_dump  dump_close  dump_file  dump_flush
-            compile  compile_nopcap  set_filter  freecode
-            dispatch  pcap_next  next_ex  loop  breakloop
+            open_live  open_dead  open_offline
+            dump_open  dump_close  dump_file  dump_flush
+            compile  compile_nopcap  setfilter  freecode
+            dispatch  next_ex  loop  breakloop
             datalink  set_datalink  datalink_name_to_val  
             datalink_val_to_name  datalink_val_to_description
-            snapshot  pcap_file  pcap_fileno  get_selectable_fd
-            is_swapped  major_version  minor_version
-            geterr strerror perror
-            lib_version
+            snapshot  get_selectable_fd
+            stats  is_swapped  major_version  minor_version
+            geterr  strerror  perror  lib_version
             createsrcstr  parsesrcstr
             setbuff  setuserbuffer  setmode  setmintocopy  getevent  sendpacket
             sendqueue_alloc  sendqueue_queue  sendqueue_transmit
-        )], 
+        ), @func_long_names ], 
     );
 
     @EXPORT = (
@@ -106,18 +136,19 @@ use Carp;
     };
 }
 
+
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
     # XS function.
 
-    no strict;
+    no strict "vars";
     my $constname;
     ($constname = $AUTOLOAD) =~ s/.*:://;
     croak "Net::Pcap::constant() not defined" if $constname eq 'constant';
     my ($error, $val) = constant($constname);
     if ($error) { croak $error; }
 
-    {   no strict 'refs';
+    {   no strict "refs";
 	# Fixed between 5.005_53 and 5.005_61
 #XXX    if ($] >= 5.00561) {
 #XXX        *$AUTOLOAD = sub () { $val };
@@ -129,34 +160,26 @@ sub AUTOLOAD {
 }
 
 
-# Functions aliases
-*Net::Pcap::pcap_open   = \&Net::Pcap::open;
-*Net::Pcap::pcap_close  = \&Net::Pcap::close;
-*Net::Pcap::pcap_next   = \&Net::Pcap::next;
-*Net::Pcap::pcap_dump   = \&Net::Pcap::dump;
-*Net::Pcap::pcap_file   = \&Net::Pcap::file;
-*Net::Pcap::pcap_fileno = \&Net::Pcap::fileno;
-
-
 # Perl wrapper for DWIM
 sub findalldevs {
-    croak "Usage: Net::Pcap::findalldevs(devinfo, err)" unless @_ and @_ <= 2 and ref $_[0];
-    
+    croak "Usage: pcap_findalldevs(devinfo, err)"
+        unless @_ and @_ <= 2 and ref $_[0];
+
     # findalldevs(\$err), legacy from Marco Carnut 0.05
     my %devinfo = ();
-    ( ref $_[0] eq 'SCALAR' and return Net::Pcap::findalldevs_xs(\%devinfo, $_[0]) ) 
+    ( ref $_[0] eq 'SCALAR' and return findalldevs_xs(\%devinfo, $_[0]) ) 
         or croak "arg1 not a scalar ref"
         if @_ == 1;
-    
+
     # findalldevs(\$err, \%devinfo), legacy from Jean-Louis Morel 0.04.02
     ref $_[0] eq 'SCALAR' and (
-        ( ref $_[1] eq 'HASH' and return Net::Pcap::findalldevs_xs($_[1], $_[0]) )
+        ( ref $_[1] eq 'HASH' and return findalldevs_xs($_[1], $_[0]) )
         or croak "arg2 not a hash ref"
     );
 
     # findalldevs(\%devinfo, \$err), new, correct syntax, consistent with libpcap(3)
     ref $_[0] eq 'HASH' and (
-        ( ref $_[1] eq 'SCALAR' and return Net::Pcap::findalldevs_xs($_[0], $_[1]) )
+        ( ref $_[1] eq 'SCALAR' and return findalldevs_xs($_[0], $_[1]) )
             or croak "arg2 not a scalar ref"
     );
 
@@ -175,23 +198,23 @@ Net::Pcap - Interface to pcap(3) LBL packet capture library
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =head1 SYNOPSIS
 
     use Net::Pcap;
 
     my $err = '';
-    my $dev = Net::Pcap::lookupdev(\$err);  # find a device
+    my $dev = pcap_lookupdev(\$err);  # find a device
 
     # open the device for live listening
-    my $pcap = Net::Pcap::open_live($dev, 1024, 1, 0, \$err);
+    my $pcap = pcap_open_live($dev, 1024, 1, 0, \$err);
 
     # loop over next 10 packets
-    Net::Pcap::loop($pcap, 10, \&process_packet, "just for the demo");
+    pcap_loop($pcap, 10, \&process_packet, "just for the demo");
 
     # close the device
-    Net::Pcap::close($pcap);
+    pcap_close($pcap);
 
     sub process_packet {
         my($user_data, $header, $packet) = @_;
@@ -282,11 +305,15 @@ C<:rpcap> exports the following constants:
 
 =item *
 
-C<:functions> exports the function names, so that you can write C<lookupdev()> 
-instead of C<Net::Pcap::lookupdev()> for example. As some functions would have 
-the same name as existing Perl functions, they have been prefixed by C<pcap_>. 
-This is the case for C<open()>, C<close()>, C<next()>, C<dump()>, C<file()>, 
-C<fileno()>. 
+C<:functions> exports the function names with the same names as the C library, 
+so you can write C<pcap_lookupdev()> instead of C<Net::Pcap::lookupdev()> 
+for example. This should also ease porting C programs to Perl. 
+
+It also exports short names of the functions (without the C<"pcap_"> prefix) 
+for those which would not cause a clash with an already defined name.
+Namely, the following functions are not available in short form: 
+C<open()>, C<close()>, C<next()>, C<dump()>, C<file()>, C<fileno()>. 
+Using these short names is now discouraged, and may be removed in the future.
 
 =back
 
@@ -299,48 +326,48 @@ All functions defined by C<Net::Pcap> are direct mappings to the
 libpcap functions.  Consult the pcap(3) documentation and source code
 for more information.
 
-Arguments that change a parameter, for example C<Net::Pcap::lookupdev()>,
+Arguments that change a parameter, for example C<pcap_lookupdev()>,
 are passed that parameter as a reference.  This is to retain
-compatibility with previous versions of B<Net::Pcap>.
+compatibility with previous versions of C<Net::Pcap>.
 
 =head2 Lookup functions
 
 =over 4
 
-=item B<lookupdev(\$err)>
-
-=item B<Net::Pcap::lookupdev(\$err)>
+=item B<pcap_lookupdev(\$err)>
 
 Returns the name of a network device that can be used with
-C<Net::Pcap::open_live()> function.  On error, the C<$err> parameter 
+C<pcap_open_live()> function.  On error, the C<$err> parameter 
 is filled with an appropriate error message else it is undefined.
 
 B<Example>
 
-    $dev = Net::Pcap::lookupdev();
+    $dev = pcap_lookupdev();
 
 
-=item B<findalldevs(\%devinfo, \$err)>
-
-=item B<Net::Pcap::findalldevs(\%devinfo, \$err)>
+=item B<pcap_findalldevs(\%devinfo, \$err)>
 
 Returns a list of all network device names that can be used with
-C<Net::Pcap::open_live()> function.  On error, the C<$err> parameter 
+C<pcap_open_live()> function.  On error, the C<$err> parameter 
 is filled with an appropriate error message else it is undefined.
 
 B<Example>
 
-    @devs = Net::Pcap::findalldevs(\%devinfo, \$err);
+    @devs = pcap_findalldevs(\%devinfo, \$err);
     for my $dev (@devs) {
         print "$dev : $devinfo{$dev}\n"
     }
 
-B<Note:> For backward compatibility reasons, this function can also 
+=over
+
+=item B<Note> 
+
+For backward compatibility reasons, this function can also 
 be called using the following signatures: 
 
-    @devs = Net::Pcap::findalldevs(\$err);
+    @devs = pcap_findalldevs(\$err);
 
-    @devs = Net::Pcap::findalldevs(\$err, \%devinfo);
+    @devs = pcap_findalldevs(\$err, \%devinfo);
 
 The first form was introduced by Marco Carnut in C<Net::Pcap> version 0.05 
 and kept intact in versions 0.06 and 0.07. 
@@ -350,10 +377,10 @@ ActivePerl port of C<Net::Pcap>, in versions 0.04.01 and 0.04.02.
 The new syntax has been introduced for consistency with the rest of the Perl 
 API and the C API of C<libpcap(3)>, where C<$err> is always the last argument. 
 
+=back
 
-=item B<lookupnet($dev, \$net, \$mask, \$err)>
 
-=item B<Net::Pcap::lookupnet($dev, \$net, \$mask, \$err)>
+=item B<pcap_lookupnet($dev, \$net, \$mask, \$err)>
 
 Determine the network number and netmask for the device specified in
 C<$dev>.  The function returns 0 on success and sets the C<$net> and
@@ -366,9 +393,7 @@ C<$err> parameter is filled with an appropriate error message.
 
 =over 4
 
-=item B<open_live($dev, $snaplen, $promisc, $to_ms, \$err)>
-
-=item B<Net::Pcap::open_live($dev, $snaplen, $promisc, $to_ms, \$err)>
+=item B<pcap_open_live($dev, $snaplen, $promisc, $to_ms, \$err)>
 
 Returns a packet capture descriptor for looking at packets on the
 network.  The C<$dev> parameter specifies which network interface to
@@ -381,14 +406,12 @@ set with an appropriate error message.
 
 B<Example>
 
-    $dev = Net::Pcap::lookupdev();
-    $pcap = Net::Pcap::open_live($dev, 1024, 1, 0, \$err)
+    $dev = pcap_lookupdev();
+    $pcap = pcap_open_live($dev, 1024, 1, 0, \$err)
         or die "Can't open device $dev: $err\n";
 
 
-=item B<open_dead($linktype, $snaplen)>
-
-=item B<Net::Pcap::open_dead($linktype, $snaplen)>
+=item B<pcap_open_dead($linktype, $snaplen)>
 
 Creates and returns a new packet descriptor to use when calling the other 
 functions in C<libpcap>. It is typically used when just using C<libpcap> 
@@ -396,27 +419,23 @@ for compiling BPF code.
 
 B<Example>
 
-    $pcap = Net::Pcap::open_dead(0, 1024);
+    $pcap = pcap_open_dead(0, 1024);
 
 
-=item B<open_offline($filename, \$err)>
-
-=item B<Net::Pcap::open_offline($filename, \$err)>
+=item B<pcap_open_offline($filename, \$err)>
 
 Return a packet capture descriptor to read from a previously created
 "savefile".  The returned descriptor is undefined if there was an
 error and in this case the C<$err> parameter will be filled.  Savefiles
-are created using the C<Net::Pcap::dump_*> commands.
+are created using the C<pcap_dump_*> commands.
 
 B<Example>
 
-    $pcap = Net::Pcap::open_offline($dump, \$err)
+    $pcap = pcap_open_offline($dump, \$err)
         or die "Can't read '$dump': $err\n";
 
 
-=item B<loop($pcap, $count, \&callback, $user_data)>
-
-=item B<Net::Pcap::loop($pcap, $count, \&callback, $user_data)>
+=item B<pcap_loop($pcap, $count, \&callback, $user_data)>
 
 Read C<$count> packets from the packet capture descriptor C<$pcap> and call
 the perl function C<&callback> with an argument of C<$user_data>.  
@@ -439,28 +458,28 @@ following fields.
 
 =over 4
 
-=item * C<len>
+=item * 
 
-The total length of the packet.
+C<len> - the total length of the packet.
 
-=item * C<caplen>
+=item * 
 
-The actual captured length of the packet data.  This corresponds to
-the snapshot length parameter passed to C<Net::Pcap::open_live()>.
+C<caplen> - the actual captured length of the packet data.  This corresponds 
+to the snapshot length parameter passed to C<open_live()>.
 
-=item * C<tv_sec>
+=item *
 
-Seconds value of the packet timestamp.
+C<tv_sec> - seconds value of the packet timestamp.
 
-=item * C<tv_usec>
+=item *
 
-Microseconds value of the packet timestamp.
+C<tv_usec> - microseconds value of the packet timestamp.
 
 =back
 
 B<Example>
 
-    Net::Pcap::loop($pcap, 10, \&process_packet, "user data");
+    pcap_loop($pcap, 10, \&process_packet, "user data");
 
     sub process_packet {
         my($user_data, $header, $packet) = @_;
@@ -468,11 +487,9 @@ B<Example>
     }
 
 
-=item B<breakloop($pcap)>
+=item B<pcap_breakloop($pcap)>
 
-=item B<Net::Pcap::breakloop($pcap)>
-
-Sets a flag  that will force C<Net::Pcap::dispatch()> or C<Net::Pcap::loop()> 
+Sets a flag  that will force C<pcap_dispatch()> or C<pcap_loop()> 
 to return rather than looping; they will return the number of packets that 
 have been processed so far, or -2 if no packets have been processed so far. 
 
@@ -486,14 +503,10 @@ information.
 
 =item B<pcap_close($pcap)>
 
-=item B<Net::Pcap::close($pcap)>
-
 Close the packet capture device associated with the descriptor C<$pcap>.
 
 
-=item B<dispatch($pcap, $count, \&callback, $user_data)>
-
-=item B<Net::Pcap::dispatch($pcap, $count, \&callback, $user_data)>
+=item B<pcap_dispatch($pcap, $count, \&callback, $user_data)>
 
 Collect C<$count> packets and process them with callback function
 C<&callback>.  if C<$count> is -1, all packets currently buffered are
@@ -502,8 +515,6 @@ processed.  If C<$count> is 0, process all packets until an error occurs.
 
 =item B<pcap_next($pcap, \%header)>
 
-=item B<Net::Pcap::next($pcap, \%header)>
-
 Return the next available packet on the interface associated with
 packet descriptor C<$pcap>.  Into the C<%header> hash is stored the received
 packet header.  If not packet is available, the return value and
@@ -512,8 +523,6 @@ header is undefined.
 
 =item B<pcap_next_ex($pcap, \%header, \$packet)>
 
-=item B<Net::Pcap::next_ex($pcap, \%header, \$packet)>
-
 Reads the next available packet on the interface associated with packet 
 descriptor C<$pcap>, stores its header in C<\%header> and its data in 
 C<\$packet> and returns a success/failure indication: 
@@ -541,9 +550,7 @@ packets to read from the savefile.
 =back
 
 
-=item B<compile($pcap, \$filter, $filter_str, $optimize, $netmask)>
-
-=item B<Net::Pcap::compile($pcap, \$filter, $filter_str, $optimize, $netmask)>
+=item B<pcap_compile($pcap, \$filter, $filter_str, $optimize, $netmask)>
 
 Compile the filter string contained in C<$filter_str> and store it in
 C<$filter>.  A description of the filter language can be found in the
@@ -554,34 +561,26 @@ function returns 0 if the compilation was successful, or -1 if there
 was a problem.
 
 
-=item B<compile_nopcap($snaplen, $linktype, \$filter, $filter_str, $optimize, $netmask)>
-
-=item B<Net::Pcap::compile_nopcap($snaplen, $linktype, \$filter, $filter_str, $optimize, $netmask)>
+=item B<pcap_compile_nopcap($snaplen, $linktype, \$filter, $filter_str, $optimize, $netmask)>
 
 Similar to C<compile()> except that instead of passing a C<$pcap> descriptor, 
 one passes C<$snaplen> and C<$linktype> directly. Returns -1 if there was an 
 error, but the error message is not available. 
 
 
-=item B<setfilter($pcap, $filter)>
-
-=item B<Net::Pcap::setfilter($pcap, $filter)>
+=item B<pcap_setfilter($pcap, $filter)>
 
 Associate the compiled filter stored in C<$filter> with the packet
 capture descriptor C<$pcap>.
 
 
-=item B<freecode($filter)>
-
-=item B<Net::Pcap::freecode($filter)>
+=item B<pcap_freecode($filter)>
 
 Used to free the allocated memory used by a compiled filter, as created 
 by C<pcap_compile()>. 
 
 
-=item B<setnonblock($pcap, $mode, \$err)>
-
-=item B<Net::Pcap::setnonblock($pcap, $mode, \$err)>
+=item B<pcap_setnonblock($pcap, $mode, \$err)>
 
 Set the I<non-blocking> mode of a live capture descriptor, depending on the 
 value of C<$mode> (zero to activate and non-zero to deactivate). It has no 
@@ -594,9 +593,7 @@ return 0  immediately rather than blocking waiting for packets to arrive.
 C<pcap_loop()> and C<pcap_next()> will not work in non-blocking mode. 
 
 
-=item B<getnonblock($pcap, \$err)>
-
-=item B<Net::Pcap::getnonblock($pcap, \$err)>
+=item B<pcap_getnonblock($pcap, \$err)>
 
 Returns the I<non-blocking> state of the capture descriptor C<$pcap>. 
 Always returns 0 on savefiles. If there is an error, it returns -1 and 
@@ -608,60 +605,50 @@ sets C<$err>.
 
 =over 4
 
-=item B<dump_open($pcap, $filename)>
-
-=item B<Net::Pcap::dump_open($pcap, $filename)>
+=item B<pcap_dump_open($pcap, $filename)>
 
 Open a savefile for writing and return a descriptor for doing so.  If
 C<$filename> is C<"-"> data is written to standard output.  On error, the
-return value is undefined and C<Net::Pcap::geterr()> can be used to
+return value is undefined and C<pcap_geterr()> can be used to
 retrieve the error text.
 
 
 =item B<pcap_dump($dumper, \%header, $packet)>
 
-=item B<Net::Pcap::dump($dumper, \%header, $packet)>
-
 Dump the packet described by header C<%header> and packet data C<$packet> 
 to the savefile associated with C<$dumper>.  The packet header has the
-same format as that passed to the C<Net::Pcap::loop()> callback.
+same format as that passed to the C<pcap_loop()> callback.
 
 B<Example>
 
     my $dump_file = 'network.dmp';
-    my $dev = Net::Pcap::lookupdev();
-    my $pcap = Net::Pcap::open_live($dev, 1024, 1, 0, \$err);
+    my $dev = pcap_lookupdev();
+    my $pcap = pcap_open_live($dev, 1024, 1, 0, \$err);
 
-    my $dumper = Net::Pcap::dump_open($pcap, $dump_file);
-    Net::Pcap::loop($pcap, 10, \&process_packet, '');
-    Net::Pcap::dump_close($dumper);
+    my $dumper = pcap_dump_open($pcap, $dump_file);
+    pcap_loop($pcap, 10, \&process_packet, '');
+    pcap_dump_close($dumper);
 
     sub process_packet {
         my($user_data, $header, $packet) = @_;
-        Net::Pcap::dump($dumper, $header, $packet);
+        pcap_dump($dumper, $header, $packet);
     }
 
 
-=item B<dump_file($dumper)>
-
-=item B<Net::Pcap::dump_file($dumper)>
+=item B<pcap_dump_file($dumper)>
 
 Returns the filehandle associated with a savefile opened with
-C<Net::Pcap::dump_open()>.
+C<pcap_dump_open()>.
 
 
-=item B<dump_flush($dumper)>
-
-=item B<Net::Pcap::dump_flush($dumper)>
+=item B<pcap_dump_flush($dumper)>
 
 Flushes the output buffer to the corresponding save file, so that any 
-packets written with C<Net::Pcap::dump()> but not yet written to the save 
+packets written with C<pcap_dump()> but not yet written to the save 
 file will be written. Returns -1 on error, 0 on success.
 
 
-=item B<dump_close($dumper)>
-
-=item B<Net::Pcap::dump_close($dumper)>
+=item B<pcap_dump_close($dumper)>
 
 Close the savefile associated with the descriptor C<$dumper>.
 
@@ -672,28 +659,22 @@ Close the savefile associated with the descriptor C<$dumper>.
 =over 4
 
 
-=item B<datalink($pcap)>
-
-=item B<Net::Pcap::datalink($pcap)>
+=item B<pcap_datalink($pcap)>
 
 Returns the link layer type associated with the given pcap descriptor.
 
 B<Example>
 
-    $linktype = Net::Pcap::datalink($pcap);
+    $linktype = pcap_datalink($pcap);
 
 
-=item B<set_datalink($pcap, $linktype)>
-
-=item B<Net::Pcap::set_datalink($pcap, $linktype)>
+=item B<pcap_set_datalink($pcap, $linktype)>
 
 Sets the data link type of the given pcap descriptor to the type specified 
 by C<$linktype>. Returns -1 on failure. 
 
 
-=item B<datalink_name_to_val($name)>
-
-=item B<Net::Pcap::datalink_name_to_val($name)>
+=item B<pcap_datalink_name_to_val($name)>
 
 Translates a data link type name, which is a C<DLT_> name with the C<DLT_> 
 part removed, to the corresponding data link type value. The translation is 
@@ -701,112 +682,95 @@ case-insensitive. Returns -1 on failure.
 
 B<Example>
 
-    $linktype = Net::Pcap::datalink_name_to_val('LTalk');  # returns DLT_LTALK
+    $linktype = pcap_datalink_name_to_val('LTalk');  # returns DLT_LTALK
 
 
-=item B<datalink_val_to_name($linktype)>
-
-=item B<Net::Pcap::datalink_val_to_name($linktype)>
+=item B<pcap_datalink_val_to_name($linktype)>
 
 Translates a data link type value to the corresponding data link type name. 
 
 B<Example>
 
-    $name = Net::Pcap::datalink_val_to_name(DLT_LTALK);  # returns 'LTALK'
+    $name = pcap_datalink_val_to_name(DLT_LTALK);  # returns 'LTALK'
 
 
-=item B<datalink_val_to_description($linktype)>
-
-=item B<Net::Pcap::datalink_val_to_description($linktype)>
+=item B<pcap_datalink_val_to_description($linktype)>
 
 Translates a data link type value to a short description of that data link type.
 
 B<Example>
 
-    $descr = Net::Pcap::datalink_val_to_description(DLT_LTALK);  # returns 'Localtalk'
+    $descr = pcap_datalink_val_to_description(DLT_LTALK);  # returns 'Localtalk'
 
 
-=item B<snapshot($pcap)>
-
-=item B<Net::Pcap::snapshot($pcap)>
+=item B<pcap_snapshot($pcap)>
 
 Returns the snapshot length (snaplen) specified in the call to
-C<Net::Pcap::open_live()>.
+C<pcap_open_live()>.
 
 
-=item B<is_swapped($pcap)>
-
-=item B<Net::Pcap::is_swapped($pcap)>
+=item B<pcap_is_swapped($pcap)>
 
 This function returns true if the endianness of the currently open
 savefile is different from the endianness of the machine.
 
 
-=item B<major_version($pcap)>
-
-=item B<Net::Pcap::major_version($pcap)>
+=item B<pcap_major_version($pcap)>
 
 Return the major version number of the pcap library used to write the
 currently open savefile.
 
 
-=item B<minor_version($pcap)>
-
-=item B<Net::Pcap::minor_version($pcap)>
+=item B<pcap_minor_version($pcap)>
 
 Return the minor version of the pcap library used to write the
 currently open savefile.
 
 
-=item B<stats($pcap, \%stats)>
-
-=item B<Net::Pcap::stats($pcap, \%stats)>
+=item B<pcap_stats($pcap, \%stats)>
 
 Returns a hash containing information about the status of packet
 capture device C<$pcap>.  The hash contains the following fields.
 
+This function is supported only on live captures, not on savefiles; 
+no statistics are stored in savefiles, so no statistics are available 
+when reading from a savefile.
+
 =over 4
 
-=item * C<ps_recv>
+=item *
 
-The number of packets received by the packet capture software.
+C<ps_recv> - the number of packets received by the packet capture software.
 
-=item * C<ps_drop>
+=item *
 
-The number of packets dropped by the packet capture software.
+C<ps_drop> - the number of packets dropped by the packet capture software.
 
-=item * C<ps_ifdrop>
+=item *
 
-The number of packets dropped by the network interface.
+C<ps_ifdrop> - the number of packets dropped by the network interface.
 
 =back
 
 
 =item B<pcap_file($pcap)>
 
-=item B<Net::Pcap::file($pcap)>
-
 Returns the filehandle associated with a savefile opened with
-C<Net::Pcap::open_offline()> or C<undef> if the device was opened 
-with C<Net::pcap::open_live()>..
+C<pcap_open_offline()> or C<undef> if the device was opened 
+with C<pcap_open_live()>.
 
 
 =item B<pcap_fileno($pcap)>
 
-=item B<Net::Pcap::fileno($pcap)>
-
-Returns the file number of the network device opened with
-C<Net::Pcap::open_live()>.
+Returns the file number of the network device opened with C<pcap_open_live()>.
 
 
-=item B<get_selectable_fd($pcap)>
-
-=item B<Net::Pcap::get_selectable_fdfileno($pcap)>
+=item B<pcap_get_selectable_fd($pcap)>
 
 Returns, on Unix, a file descriptor number for a file descriptor on which 
 one can do a C<select()> or C<poll()> to wait for it to be possible to read 
 packets without blocking, if such a descriptor exists, or -1, if no such 
-descriptor exists. Some network devices opened with C<Net::Pcap::open_live()> 
+descriptor exists. Some network devices opened with C<pcap_open_live()> 
 do not support C<select()> or C<poll()>, so -1 is returned for those devices.
 See L<pcap(3)> for more details. 
 
@@ -816,24 +780,18 @@ See L<pcap(3)> for more details.
 
 =over 4
 
-=item B<geterr($pcap)>
-
-=item B<Net::Pcap::geterr($pcap)>
+=item B<pcap_geterr($pcap)>
 
 Returns an error message for the last error associated with the packet
 capture device C<$pcap>.
 
 
-=item B<strerror($errno)>
-
-=item B<Net::Pcap::strerror($errno)>
+=item B<pcap_strerror($errno)>
 
 Returns a string describing error number C<$errno>.
 
 
-=item B<perror($pcap, $prefix)>
-
-=item B<Net::Pcap::perror($pcap, $prefix)>
+=item B<pcap_perror($pcap, $prefix)>
 
 Prints the text of the last error associated with descriptor C<$pcap> on
 standard error, prefixed by C<$prefix>.
@@ -844,9 +802,7 @@ standard error, prefixed by C<$prefix>.
 
 =over 4
 
-=item B<lib_version()>
-
-=item B<Net::Pcap::lib_version()>
+=item B<pcap_lib_version()>
 
 Returns the name and version of the C<pcap> library the module was linked 
 against. 
@@ -862,30 +818,26 @@ C<croak()>.
 
 =over 4
 
-=item B<createsrcstr(\$source, $type, $host, $port, $name, \$err)>
-
-=item B<Net::Pcap::createsrcstr(\$source, $type, $host, $port, $name, \$err)>
+=item B<pcap_createsrcstr(\$source, $type, $host, $port, $name, \$err)>
 
 Accepts a set of strings (host name, port, ...), and stores the complete 
 source string according to the new format (e.g. C<"rpcap://1.2.3.4/eth0">) 
 in C<$source>.
 
-This function is provided in order to help the user creating the source string 
-according to the new format. An unique source string is used in order to make 
-easy for old applications to use the remote facilities. Think about B<tcpdump(1)>, 
-for example, which has only one way to specify the interface on which the capture 
-has to be started. However, GUI-based programs can find more useful to specify 
-hostname, port and interface name separately. In that case, they can use this 
-function to create the source string before passing it to the C<pcap_open()> 
-function.
+This function is provided in order to help the user creating the source 
+string according to the new format. An unique source string is used in 
+order to make easy for old applications to use the remote facilities. 
+Think about B<tcpdump(1)>, for example, which has only one way to specify 
+the interface on which the capture has to be started. However, GUI-based 
+programs can find more useful to specify hostname, port and interface name 
+separately. In that case, they can use this function to create the source 
+string before passing it to the C<pcap_open()> function.
 
 Returns 0 if everything is fine, -1 if some errors occurred. The string 
 containing the complete source is returned in the C<$source> variable.
 
 
-=item B<parsesrcstr($source, \$type, \$host, \$port, \$name, \$err)>
-
-=item B<Net::Pcap::parsesrcstr($source, \$type, \$host, \$port, \$name, \$err)>
+=item B<pcap_parsesrcstr($source, \$type, \$host, \$port, \$name, \$err)>
 
 Parse the source string and stores the pieces in which the source can be split 
 in the corresponding variables.
@@ -924,8 +876,6 @@ proper variables passed by reference.
 
 =item B<pcap_open($source, $snaplen, $flags, $read_timeout, \$auth, \$err)>
 
-=item B<Net::Pcap::open($source, $snaplen, $flags, $read_timeout, \$auth, \$err)>
-
 Open a generic source in order to capture / send (WinPcap only) traffic.
 
 The C<pcap_open()> replaces all the C<pcap_open_xxx()> functions with a single 
@@ -933,9 +883,9 @@ call.
 
 This function hides the differences between the different C<pcap_open_xxx()> 
 functions so that the programmer does not have to manage different opening 
-function. In this way, the I<true> C<open()> function is decided according to the 
-source type, which is included into the source string (in the form of source 
-prefix).
+function. In this way, the I<true> C<open()> function is decided according 
+to the source type, which is included into the source string (in the form of 
+source prefix).
 
 Returns a pointer to a pcap descriptor which can be used as a parameter to 
 the following calls (C<compile()> and so on) and that specifies an opened 
@@ -943,9 +893,7 @@ WinPcap session. In case of problems, it returns C<undef> and the C<$err>
 variable keeps the error message.
 
 
-=item B<setbuff($pcap, $dim)>
-
-=item B<Net::Pcap::setbuff($pcap, $dim)>
+=item B<pcap_setbuff($pcap, $dim)>
 
 Sets the size of the kernel buffer associated with an adapter.
 C<$dim> specifies the size of the buffer in bytes.
@@ -956,42 +904,27 @@ C<setbuff()>, it is deleted and its content is discarded.
 C<open_live()> creates a S<1 MB> buffer by default.
 
 
-=item B<setuserbuffer($pcap, $size)>
-
-=item B<Net::Pcap::setbuff($pcap, $size)>
-
-I<Note: Undocumented public function>
-
-
-=item B<setmode($pcap, $mode)>
-
-=item B<Net::Pcap::setmode($pcap, $mode)>
+=item B<pcap_setmode($pcap, $mode)>
 
 Sets the working mode of the interface C<$pcap> to C<$mode>.
 Valid values for C<$mode> are C<MODE_CAPT> (default capture mode) and
 C<MODE_STAT> (statistical mode).
 
 
-=item B<setmintocopy($pcap, $size)>
-
-=item B<Net::Pcap::setmintocopy($pcap_t, $size)>
+=item B<pcap_setmintocopy($pcap_t, $size)>
 
 Changes the minimum amount of data in the kernel buffer that causes a read
 from the application to return (unless the timeout expires).
 
 
-=item B<getevent($pcap)>
-
-=item B<Net::Pcap::getevent($pcap)>
+=item B<pcap_getevent($pcap)>
 
 Returns the C<Win32::Event> object associated with the interface 
 C<$pcap>. Can be used to wait until the driver's buffer contains some 
 data without performing a read. See L<Win32::Event>.
 
 
-=item B<sendpacket($pcap, $packet)>
-
-=item B<Net::Pcap::sendpacket($pcap, $packet)>
+=item B<pcap_sendpacket($pcap, $packet)>
 
 Send a raw packet to the network. C<$pcap> is the interface that will be
 used to send the packet, C<$packet> contains the data of the packet to send
@@ -1001,9 +934,7 @@ interface driver. The return value is 0 if the packet is successfully sent,
 -1 otherwise.
 
 
-=item B<sendqueue_alloc($memsize)>
-
-=item B<Net::Pcap::sendqueue_alloc($memsize)>
+=item B<pcap_sendqueue_alloc($memsize)>
 
 This function allocates and returns a send queue, i.e. a buffer containing 
 a set of raw packets that will be transmitted on the network with 
@@ -1014,9 +945,7 @@ the maximum amount of data that the queue will contain. This memory is
 automatically deallocated when the queue ceases to exist.
 
 
-=item B<sendqueue_queue($queue, \%header, $packet)>
-
-=item B<Net::Pcap::sendqueue_queue($queue, \%header, $packet)>
+=item B<pcap_sendqueue_queue($queue, \%header, $packet)>
 
 Adds a packet at the end of the send queue pointed by C<$queue>. The packet
 header C<%header> has the same format as that passed to the C<loop()> 
@@ -1030,9 +959,7 @@ I<as is>. The CRC of the packets needs not to be calculated, because it will
 be transparently added by the network interface.
 
 
-=item B<sendqueue_transmit($pcap, $queue, $sync)>
-
-=item B<Net::Pcap::sendqueue_transmit($pcap, $queue, $sync)>
+=item B<pcap_sendqueue_transmit($pcap, $queue, $sync)>
 
 This function transmits the content of a queue to the wire. C<$pcapt> is
 the interface on which the packets will be sent, C<$queue> is to a
@@ -1131,11 +1058,11 @@ C<DLT_APPLE_IP_OVER_IEEE1394> - Apple IP-over-IEEE 1394 (a.k.a. Firewire)
 
 =over 4
 
-=item arg%d not a scalar ref
+=item C<arg%d not a scalar ref>
 
-=item arg%d not a hash ref
+=item C<arg%d not a hash ref>
 
-=item arg%d not a reference
+=item C<arg%d not a reference>
 
 B<(F)> These errors occur if you forgot to give a reference to a function 
 which expect one or more of its arguments to be references.
@@ -1175,20 +1102,20 @@ the C<ps_recv> field is not correctly set; see F<t/07-stats.t>
 
 =item *
 
-C<Net::Pcap::file()> seems to always returns C<undef> for live 
+C<pcap_file()> seems to always returns C<undef> for live 
 connection and causes segmentation fault for dump files; 
 see F<t/10-fileno.t>
 
 =item *
 
-C<Net::Pcap::fileno()> is documented to return -1 when called 
+C<pcap_fileno()> is documented to return -1 when called 
 on save file, but seems to always return an actual file number. 
 See F<t/10-fileno.t>
 
 
 =item *
 
-C<Net::Pcap::dump_file()> seems to corrupt something somewhere, 
+C<pcap_dump_file()> seems to corrupt something somewhere, 
 and makes scripts dump core. See F<t/05-dump.t>
 
 =back
@@ -1202,17 +1129,30 @@ for examples on using this module.
 
 =head1 SEE ALSO
 
+=head2 Perl Modules
+
+L<Net::Pcap::Reassemble> for reassembly of TCP/IP fragments.
+
+L<POE::Component::Pcap> for using C<Net::Pcap> within POE-based programs.
+
+L<Net::Packet> or L<NetPacket> for decoding and creating network packets.
+
+=head2 Base Libraries
+
 L<pcap(3)>, L<tcpdump(8)>
 
-The source code for the C<pcap(3)> library is available from L<http://www.tcpdump.org/>
+The source code for the C<pcap(3)> library is available from 
+L<http://www.tcpdump.org/>
 
-The source code and binary for the Win32 version of the pcap library, WinPcap, 
-is available from L<http://www.winpcap.org/>
+The source code and binary for the Win32 version of the pcap library, 
+WinPcap, is available from L<http://www.winpcap.org/>
 
-I<Hacking Linux Exposed: Sniffing with Net::Pcap to stealthily managing iptables rules remotely>, 
-L<http://www.hackinglinuxexposed.com/articles/20030730.html>
+=head2 Articles
 
-I<PerlMonks node about C<Net::Pcap>>, L<http://perlmonks.org/?node_id=170648>
+I<Hacking Linux Exposed: Sniffing with Net::Pcap to stealthily managing iptables 
+rules remotely>, L<http://www.hackinglinuxexposed.com/articles/20030730.html>
+
+I<PerlMonks node about Net::Pcap>, L<http://perlmonks.org/?node_id=170648>
 
 
 =head1 AUTHORS
@@ -1254,13 +1194,14 @@ To the beta-testers: Jean-Louis Morel, Max Maischen, Philippe Bruhat,
 David Morel, Scott Lanning, Rafael Garcia-Suarez, Karl Y. Pradene.
 
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2005, 2006 SE<eacute>bastien Aperghis-Tramoni. All rights reserved. 
+Copyright (C) 2005, 2006, 2007 SE<eacute>bastien Aperghis-Tramoni.
+All rights reserved. 
 
 Copyright (C) 2003 Marco Carnut. All rights reserved. 
 
-Copyright (C) 1999-2000 Tim Potter. All rights reserved. 
+Copyright (C) 1999, 2000 Tim Potter. All rights reserved. 
 
 Copyright (C) 1998 Bo Adler. All rights reserved. 
 
